@@ -37,7 +37,7 @@ import org.apache.commons.jexl2.parser.Parser;
  *
  *  @since 1.0
  *  @author <a href="mailto:geirm@apache.org">Geir Magnusson Jr.</a>
- *  @version $Id: JexlTest.java 889627 2009-12-11 14:07:21Z henrib $
+ *  @version $Id: JexlTest.java 929351 2010-03-31 00:41:17Z sebb $
  */
 public class JexlTest extends JexlTestCase
 {
@@ -309,7 +309,7 @@ public class JexlTest extends JexlTestCase
         jc.set("aDouble", new Double(2));
         jc.set("aChar", new Character('A'));
         jc.set("aBool", Boolean.TRUE);
-        StringBuffer buffer = new StringBuffer("abc");
+        StringBuilder buffer = new StringBuilder("abc");
         List<Object> list = new ArrayList<Object>();
         List<Object> list2 = new LinkedList<Object>();
         jc.set("aBuffer", buffer);
